STOP

** First dofile to create merged Milo and OSCR datafiles

*** edit the following to point to your copy of SCSDP WP1 subdirectory
global wp1="C:\Users\ob3\Dropbox\ScottishCSDP\wp1-datacuration\"


**** import milo data
*** Run the "Stirling Data Extract" report from Salesforce, filed in public reports 
*** save as "milo with aims.txt" within "wp1\MILO" directory
clear 
import delimited "$wp1\MILO\milo with aims.csv", ///
delimiter(comma) varnames(1) bindquote(strict) 

ren organisationname orgname
ren organisationid orgid
ren parentorganisationid parentorg
ren organisationtype orgtype
ren aimsandobjectives aims
ren registeredcharitynumber regcharno

drop if orgid==""
drop employees noofvolunteers
ren v19 noofvolunteers annual
compress
save "$wp1\MILO\milo_aims.dta", replace

**** save parent data file (to fill in details of parent orgs)
drop parentorg
ren orgid parentorg 
drop par_*
ren postcode par_pcode
ren orgname par_orgname
ren aims par_aims
ren regcharno par_regchar
keep par*
save "$wp1\MILO\parentorgs.dta", replace
clear

**** join parent org data
use "$wp1\MILO\milo_aims.dta"
merge m:1 parentorg using "$wp1\MILO\parentorgs.dta", update
drop if _merge==2
drop _merge
save "$wp1\MILO\milo_aims.dta", replace


**** join milo to ncvo class
capture drop _merge
gen sc_num=regcharno
merge m:1 sc_num using "$wp1\NCVO classification\ncvo_class.dta"

drop if _merge==2
drop _merge
save, replace

**** join ncvo via parentorg if above not matched
replace sc_num=par_regchar 
merge m:1 sc_num using ///
"$wp1\NCVO classification\ncvo_class.dta" ///
, update
drop if _merge==2
replace icnpohow="Parent" if _merge==4
drop _merge
replace icnpo="3300 Mental Health" if substr(icnpo,1,4)=="3300" 
save, replace 

gen orgname_lower = lower(orgname)
gen aims_lower = lower(aims)
format %50s orgname par_oname
format %25s aims icnpo

save, replace


**** Download public OSCR dataset 
*** save as "oscrpublic.csv" within the wp1\oscr directory
clear
import delimited "$wp1\oscr\oscrpublic.csv", ///
delimiter(comma) varnames(1) bindquote(strict) 
ren postcode oscr_postcode
compress 
save "$wp1\oscr\oscrpublic.dta", replace
clear

****** clean charity numbers
****** start by establishing regcharnos which already match oscr register
use "$wp1\MILO\milo_aims.dta"
capture drop charityname _merge regchar2 charitynumber
gen charitynumber=regcharno

merge m:1 charitynumber using ///
"$wp1\oscr\oscrpublic.dta" ///
, update

drop if _merge==2
gen regcharcln=regcharno if _merge>=3
drop _merge

*** create temporary field, regchar2, if original regcharno didn't find a match
*** clean this field and look for matched against oscr register

gen regchar2=regcharno if regcharcln==""
replace regchar2 = subinstr(regchar2,"&","",.)
replace regchar2 = subinstr(regchar2,"(","",.)
replace regchar2 = subinstr(regchar2,")","",.)
replace regchar2 = subinstr(regchar2,",","",.)
replace regchar2 = subinstr(regchar2,"-","",.)
replace regchar2 = subinstr(regchar2,".","",.)
replace regchar2 = subinstr(regchar2,"/","",.)
replace regchar2 = subinstr(regchar2,":","",.)
replace regchar2 = subinstr(regchar2," ","",.)
replace regchar2 = upper(regchar2)
replace regchar2 = subinstr(regchar2,"A","",.)
replace regchar2 = subinstr(regchar2,"B","",.)
replace regchar2 = subinstr(regchar2,"D","",.)
replace regchar2 = subinstr(regchar2,"E","",.)
replace regchar2 = subinstr(regchar2,"F","",.)
replace regchar2 = subinstr(regchar2,"G","",.)
replace regchar2 = subinstr(regchar2,"H","",.)
replace regchar2 = subinstr(regchar2,"I","",.)
replace regchar2 = subinstr(regchar2,"J","",.)
replace regchar2 = subinstr(regchar2,"K","",.)
replace regchar2 = subinstr(regchar2,"L","",.)
replace regchar2 = subinstr(regchar2,"M","",.)
replace regchar2 = subinstr(regchar2,"N","",.)
replace regchar2 = subinstr(regchar2,"O","0",.)
replace regchar2 = subinstr(regchar2,"P","",.)
replace regchar2 = subinstr(regchar2,"R","",.)
replace regchar2 = subinstr(regchar2,"T","",.)
replace regchar2 = subinstr(regchar2,"U","",.)
replace regchar2 = subinstr(regchar2,"V","",.)
replace regchar2 = subinstr(regchar2,"W","",.)
replace regchar2 = subinstr(regchar2,"X","",.)
replace regchar2 = subinstr(regchar2,"Y","",.)
replace regchar2="SC" + regchar2 if length(regchar2)==6 & substr(regchar2,1,1)=="0"
replace regchar2="SC0" + regchar2 if length(regchar2)==5 
replace regchar2="SC00" + regchar2 if length(regchar2)==4
replace regchar2="SC" + substr(regchar2,4,6) if length(regchar2)==9 & ///
substr(regchar2,3,2)=="00"

replace regchar2="SC0" + substr(regchar2,3,5) if length(regchar2)==7 /// 
& substr(regchar2,1,2)=="SC"

save, replace

replace charitynumber=regchar2

merge m:1 charitynumber using ///
"$wp1\oscr\oscrpublic.dta" ///
, update
drop if _merge==2

**** if org wasn't previously matched to oscr and now has been, keep this clean ////
**** charity number
replace regcharcln=regchar2 if _merge==4

drop _merge
save, replace

*** now follow the same steps with parent char no: match using original field contents

capture drop parchar2 
replace charitynumber=par_regchar
merge m:1 charitynumber using ///
"$wp1\oscr\oscrpublic.dta" ///
, update

drop if _merge==2

*** keep parent charity number if it matched (and wasn't already matched)

replace regcharcln=par_regchar if _merge==4
drop _merge

**** clean parent charity number

replace regchar2 =par_regchar if regcharcln==""
replace regchar2 = subinstr(regchar2,"&","",.)
replace regchar2 = subinstr(regchar2,"(","",.)
replace regchar2 = subinstr(regchar2,")","",.)
replace regchar2 = subinstr(regchar2,",","",.)
replace regchar2 = subinstr(regchar2,"-","",.)
replace regchar2 = subinstr(regchar2,".","",.)
replace regchar2 = subinstr(regchar2,"/","",.)
replace regchar2 = subinstr(regchar2,":","",.)
replace regchar2 = subinstr(regchar2," ","",.)
replace regchar2 = upper(regchar2)
replace regchar2 = subinstr(regchar2,"A","",.)
replace regchar2 = subinstr(regchar2,"B","",.)
replace regchar2 = subinstr(regchar2,"D","",.)
replace regchar2 = subinstr(regchar2,"E","",.)
replace regchar2 = subinstr(regchar2,"F","",.)
replace regchar2 = subinstr(regchar2,"G","",.)
replace regchar2 = subinstr(regchar2,"H","",.)
replace regchar2 = subinstr(regchar2,"I","",.)
replace regchar2 = subinstr(regchar2,"J","",.)
replace regchar2 = subinstr(regchar2,"K","",.)
replace regchar2 = subinstr(regchar2,"L","",.)
replace regchar2 = subinstr(regchar2,"M","",.)
replace regchar2 = subinstr(regchar2,"N","",.)
replace regchar2 = subinstr(regchar2,"O","0",.)
replace regchar2 = subinstr(regchar2,"P","",.)
replace regchar2 = subinstr(regchar2,"R","",.)
replace regchar2 = subinstr(regchar2,"T","",.)
replace regchar2 = subinstr(regchar2,"U","",.)
replace regchar2 = subinstr(regchar2,"V","",.)
replace regchar2 = subinstr(regchar2,"W","",.)
replace regchar2 = subinstr(regchar2,"X","",.)
replace regchar2 = subinstr(regchar2,"Y","",.)
replace regchar2="SC" + regchar2 if length(regchar2)==6 & substr(regchar2,1,1)=="0"
replace regchar2="SC0" + regchar2 if length(regchar2)==5 
replace regchar2="SC00" + regchar2 if length(regchar2)==4
replace regchar2="SC" + substr(regchar2,4,6) if length(regchar2)==9 & ///
substr(regchar2,3,2)=="00"

replace regchar2="SC0" + substr(regchar2,3,5) if length(regchar2)==7 /// 
& substr(regchar2,1,2)=="SC"

sort regchar2
capture drop _merge
save "$wp1\MILO\milo_aims.dta", replace

**** now try matching with cleaned parent charity number 
replace charitynumber=regchar2

merge m:1 charitynumber using ///
"$wp1\oscr\oscrpublic.dta" ///
, update
drop if _merge==2

**** keep cleaned parent charity number if it matched (and hadn't previously)
replace regcharcln=regchar2 if _merge==4

drop if _merge==2
drop _merge
save, replace

