STOP

**** Prior to running this syntax download a postcode directory from ukdataservice.ac.uk ///
**** or geoportal.statistics.gov.uk and import into Stata.
**** Create a field pcns : gen pcns=subinstr(postcode," ","",.)
**** Save as ONSPDNOV15 or change the filename below.  ///

**** Documentation for the postcode directory includes lookups from the codes 
**** to the names for Government Office Region (GOR) and Local Authorities.
**** import these to Stata and save them in the same directory, as  ////
**** gorlookup.dta and lacodelookup2015.dta respectively

**** The Scottish Indices of Multiple Deprivation (SIMD) data should be downloaded ///
**** from the Information Services Division of NHS Scotland, here ///
**** http://www.isdscotland.org/Products-and-Services/GPD-Support/Deprivation/SIMD/
**** Save as isdpclookup.dta in the same directory as used above

*** edit this to point to the directory where you have stored these files
global geog = "C:\Users\Public\Documents"

use "$wp1\MILO\milo_aims.dta", clear

replace postcode=subinstr(postcode,"!","",.)
replace postcode=subinstr(postcode,"'","",.)
replace postcode=subinstr(postcode,".","",.)
replace postcode=subinstr(postcode,"/","",.)
replace postcode=subinstr(postcode,"(","",.)
replace postcode=subinstr(postcode,"-","",.)
replace postcode=subinstr(postcode,",","",.)
replace postcode=subinstr(postcode,"?","",.)
replace postcode=subinstr(postcode,"%","",.)
replace postcode=subinstr(postcode,";","",.)
replace postcode=subinstr(postcode,"&","",.)
replace postcode=strtrim(postcode)
replace postcode=ustrtrim(postcode)
replace postcode=upper(postcode)

gen pcns=subinstr(postcode," ","",.)

charlist pcns
recast str7 pcns, force

save, replace


**** merge with postcode directory to add geographic identifiers

merge m:1 pcns using "$geog\ONSPDNOV15.dta" , ///
keep(match master match_up match_con) update
drop _merge
save, replace
tab gor
tab oslau
capture drop GOR10CD
ren gor GOR10CD

*** looks up names for codes
merge m:1 GOR10CD using "$geog\gorlookup.dta", ///
keep(match master match_up match_con) update 

***** GOR codes cover Regions of England, plus Nations
replace GOR10NM= "Wales" if GOR10CD=="W99999999"
replace GOR10NM= "Scotland" if GOR10CD=="S99999999"
replace GOR10NM= "Northern Ireland" if GOR10CD=="N99999999"
replace GOR10NM= "Channel Islands" if GOR10CD=="L99999999"

drop _merge
*** create separate "missing" codes for non-matched and empty postcodes
replace GOR10NM="ZZ Not matched" if GOR10NM=="" & pcns>""
replace GOR10NM="ZZZ Empty" if pcns==""  
save, replace

**** Add local authority names
capture drop LAD15CD
rename oslau LAD15CD
merge m:1 LAD15CD using "$geog\lacodelookup2015.dta", ///
keep(match master match_up match_con) update
drop if _merge==2
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="E"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="W"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="N"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="L"
replace LAD15NM="ZZ Not matched" if LAD15NM=="" & pcns>""
replace LAD15NM="ZZZ Empty" if pcns==""
drop _merge
save, replace
tab LAD15NM

***** merge in simd NB using NHS Scotland's population weighted quintiles
capture drop _merge
merge m:1 pcns using "$geog\isdpclookup.dta" , ///
keepusing(simd2012_sc*) keep(match master) update
drop _merge
save, replace

***** Repeat this process with the OSCR file (the geographic identifiers are using for matching)
use "$wp1\oscr\oscrpublic.dta", clear

replace oscr_postcode=subinstr(oscr_postcode,"!","",.)
replace oscr_postcode=subinstr(oscr_postcode,"'","",.)
replace oscr_postcode=subinstr(oscr_postcode,".","",.)
replace oscr_postcode=subinstr(oscr_postcode,"/","",.)
replace oscr_postcode=subinstr(oscr_postcode,"(","",.)
replace oscr_postcode=subinstr(oscr_postcode,"-","",.)
replace oscr_postcode=subinstr(oscr_postcode,",","",.)
replace oscr_postcode=subinstr(oscr_postcode,"?","",.)
replace oscr_postcode=subinstr(oscr_postcode,"%","",.)
replace oscr_postcode=subinstr(oscr_postcode,";","",.)
replace oscr_postcode=subinstr(oscr_postcode,"&","",.)
replace oscr_postcode=strtrim(oscr_postcode)
replace oscr_postcode=ustrtrim(oscr_postcode)
replace oscr_postcode=upper(oscr_postcode)

gen pcns=subinstr(oscr_postcode," ","",.)

charlist pcns
recast str7 pcns, force

save, replace


**** merge with postcode directory to add geographic identifiers

merge m:1 pcns using "$geog\ONSPDNOV15.dta" , ///
keep(match master match_up match_con) update
drop _merge
save, replace
tab gor
tab oslau
capture drop GOR10CD
ren gor GOR10CD

*** looks up names for codes
merge m:1 GOR10CD using "$geog\gorlookup.dta", ///
keep(match master match_up match_con) update 

***** Most will not match as GOR names cover Regions of England: 
***** Nations have their own "Missing" codes
replace GOR10NM= "Wales" if GOR10CD=="W99999999"
replace GOR10NM= "Scotland" if GOR10CD=="S99999999"
replace GOR10NM= "Northern Ireland" if GOR10CD=="N99999999"
replace GOR10NM= "Channel Islands" if GOR10CD=="L99999999"

drop _merge
*** create separate "missing" codes for non-matched and empty postcodes
replace GOR10NM="ZZ Not matched" if GOR10NM=="" & pcns>""
replace GOR10NM="ZZZ Empty" if pcns==""  
save, replace

**** Add local authority names
capture drop LAD15CD
rename oslau LAD15CD
merge m:1 LAD15CD using "$geog\lacodelookup2015.dta", ///
keep(match master match_up match_con) update
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="E"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="W"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="N"
replace LAD15NM="Z Out of Scotland" if substr(GOR10CD,1,1)=="L"
replace LAD15NM="ZZ Not matched" if LAD15NM=="" & pcns>""
replace LAD15NM="ZZZ Empty" if pcns==""
drop _merge
save, replace
tab LAD15NM

***** merge SIMD using NHS Scotland's population weighted quintiles
merge m:1 pcns using "$geog\isdpclookup.dta" , ///
keepusing(simd2012_sc*) keep(match master) update
drop _merge
save, replace
